EXPORTS
	??1CXmlPullParser@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CXmlPullParser::~CXmlPullParser(void)
	??1CXmlWriter@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CXmlWriter::~CXmlWriter(void)
	?AddAttributeL@CXmlWriter@@UAEXABVTDesC8@@0@Z @ 3 NONAME ; public: virtual void __thiscall CXmlWriter::AddAttributeL(class TDesC8 const &,class TDesC8 const &)
	?AddCdataSectL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 4 NONAME ; public: virtual void __thiscall CXmlWriter::AddCdataSectL(class TDesC8 const &)
	?AddEndTagL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 5 NONAME ; public: virtual void __thiscall CXmlWriter::AddEndTagL(class TDesC8 const &)
	?AddPrologL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 6 NONAME ; public: virtual void __thiscall CXmlWriter::AddPrologL(class TDesC8 const &)
	?AddPrologL@CXmlWriter@@UAEXXZ @ 7 NONAME ; public: virtual void __thiscall CXmlWriter::AddPrologL(void)
	?AddStartTagL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 8 NONAME ; public: virtual void __thiscall CXmlWriter::AddStartTagL(class TDesC8 const &)
	?AddTextL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 9 NONAME ; public: virtual void __thiscall CXmlWriter::AddTextL(class TDesC8 const &)
	?AttributeCount@CXmlPullParser@@UAEHAAH@Z @ 10 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeCount(int &)
	?AttributeName@CXmlPullParser@@UAEHHAAVTPtrC8@@@Z @ 11 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeName(int,class TPtrC8 &)
	?AttributeValueL@CXmlPullParser@@UAEHABVTDesC8@@AAVTPtrC8@@@Z @ 12 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeValueL(class TDesC8 const &,class TPtrC8 &)
	?AttributeValueL@CXmlPullParser@@UAEHHAAVTPtrC8@@@Z @ 13 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeValueL(int,class TPtrC8 &)
	?AttributeValuePredefEntitiesNotEscaped@CXmlPullParser@@UAEHABVTDesC8@@AAVTPtrC8@@@Z @ 14 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeValuePredefEntitiesNotEscaped(class TDesC8 const &,class TPtrC8 &)
	?AttributeValuePredefEntitiesNotEscaped@CXmlPullParser@@UAEHHAAVTPtrC8@@@Z @ 15 NONAME ; public: virtual int __thiscall CXmlPullParser::AttributeValuePredefEntitiesNotEscaped(int,class TPtrC8 &)
	?CloseStartTagL@CXmlWriter@@UAEXH@Z @ 16 NONAME ; public: virtual void __thiscall CXmlWriter::CloseStartTagL(int)
	?CurrentElementPos@CXmlPullParser@@UAEHXZ @ 17 NONAME ; public: virtual int __thiscall CXmlPullParser::CurrentElementPos(void)
	?Depth@CXmlPullParser@@UAEHAAH@Z @ 18 NONAME ; public: virtual int __thiscall CXmlPullParser::Depth(int &)
	?DocPart@CXmlPullParser@@UAE?AVTPtrC8@@HH@Z @ 19 NONAME ; public: virtual class TPtrC8  __thiscall CXmlPullParser::DocPart(int,int)
	?DocPart@CXmlWriter@@UAE?AVTPtrC8@@HH@Z @ 20 NONAME ; public: virtual class TPtrC8  __thiscall CXmlWriter::DocPart(int,int)
	?InsertTextL@CXmlWriter@@UAEXHABVTDesC8@@@Z @ 21 NONAME ; public: virtual void __thiscall CXmlWriter::InsertTextL(int,class TDesC8 const &)
	?IsEmptyElement@CXmlPullParser@@UAEHAAH@Z @ 22 NONAME ; public: virtual int __thiscall CXmlPullParser::IsEmptyElement(int &)
	?Length@CXmlPullParser@@UAEHXZ @ 23 NONAME ; public: virtual int __thiscall CXmlPullParser::Length(void)
	?Length@CXmlWriter@@UAEHXZ @ 24 NONAME ; public: virtual int __thiscall CXmlWriter::Length(void)
	?Name@CXmlPullParser@@UAEHAAVTPtrC8@@@Z @ 25 NONAME ; public: virtual int __thiscall CXmlPullParser::Name(class TPtrC8 &)
	?NewL@CXmlPullParser@@SAPAV1@AAVCDesC8ArrayFlat@@@Z @ 26 NONAME ; public: static class CXmlPullParser * __cdecl CXmlPullParser::NewL(class CDesC8ArrayFlat &)
	?NewL@CXmlWriter@@SAPAV1@XZ @ 27 NONAME ; public: static class CXmlWriter * __cdecl CXmlWriter::NewL(void)
	?NewLC@CXmlPullParser@@SAPAV1@AAVCDesC8ArrayFlat@@@Z @ 28 NONAME ; public: static class CXmlPullParser * __cdecl CXmlPullParser::NewLC(class CDesC8ArrayFlat &)
	?NewLC@CXmlWriter@@SAPAV1@XZ @ 29 NONAME ; public: static class CXmlWriter * __cdecl CXmlWriter::NewLC(void)
	?NextL@CXmlPullParser@@UAEHXZ @ 30 NONAME ; public: virtual int __thiscall CXmlPullParser::NextL(void)
	?OpenStartTagL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 31 NONAME ; public: virtual void __thiscall CXmlWriter::OpenStartTagL(class TDesC8 const &)
	?PathL@CXmlPullParser@@UAEHAAVTPtrC8@@@Z @ 32 NONAME ; public: virtual int __thiscall CXmlPullParser::PathL(class TPtrC8 &)
	?Pos@CXmlPullParser@@UAEHXZ @ 33 NONAME ; public: virtual int __thiscall CXmlPullParser::Pos(void)
	?Reset@CXmlWriter@@UAEXXZ @ 34 NONAME ; public: virtual void __thiscall CXmlWriter::Reset(void)
	?SetInput@CXmlPullParser@@UAEXABVTDesC8@@@Z @ 35 NONAME ; public: virtual void __thiscall CXmlPullParser::SetInput(class TDesC8 const &)
	?State@CXmlPullParser@@UAE?AW4TParserState@MXmlPullParser@@XZ @ 36 NONAME ; public: virtual enum MXmlPullParser::TParserState  __thiscall CXmlPullParser::State(void)
	?TextL@CXmlPullParser@@UAEHAAVTPtrC8@@@Z @ 37 NONAME ; public: virtual int __thiscall CXmlPullParser::TextL(class TPtrC8 &)
	?TextPredefEntitiesNotEscaped@CXmlPullParser@@UAEHAAVTPtrC8@@@Z @ 38 NONAME ; public: virtual int __thiscall CXmlPullParser::TextPredefEntitiesNotEscaped(class TPtrC8 &)
	?AddXmlTextL@CXmlWriter@@UAEXABVTDesC8@@@Z @ 39 NONAME ; public: virtual void __thiscall CXmlWriter::AddXmlTextL(class TDesC8 const &)
	?InsertXmlTextL@CXmlWriter@@UAEXHABVTDesC8@@@Z @ 40 NONAME ; public: virtual void __thiscall CXmlWriter::InsertXmlTextL(int,class TDesC8 const &)

